
dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
dialogStr("E’ di nuovo caduta della roba.")


dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
dialogStr("E’ una specie di conchiglia. Mi sa che dovremo di nuovo portarla su.")


dialogId("sch-v-setkani", "font_big", "I can see it now: ‘Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
dialogStr("Ora vedo: 'La conchiglia incontra il vaso'. E’ più o meno come un ferro da stiro e una sega elettrica che si incontrano su un tavolo operatorio.")


dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
dialogStr("Scusa, mi sono lasciata trasportare.")


dialogId("sch-m-moc1", "font_small", "Sorry, I was momentarily distracted.")
dialogStr("Scusa, mi sono distratta un attimo.")


dialogId("sch-m-moc2", "font_small", "Where I am going with this shell?")
dialogStr("Dove vado con 'sta conchiglia?")

